import 'dotenv/config';
import { db } from './models';
import { restRouter } from './api';
import config from './config';
import appManager from './app';
// import kue from './kue';
import './errors';
// import scheduler from './scheduler';
import path from 'path';
import cors from 'cors';
global.appRoot = path.resolve(__dirname);
const PORT = config.app.port;
const app = appManager.setup(config);

app.use(cors())
global.imapList = {};

app.use(function(req, res, next) {
    res.header("Access-Control-Allow-Origin", "YOUR-DOMAIN.TLD"); // update to match the domain you will make the request from
    res.header("Access-Control-Allow-Headers", "Origin, X-Requested-With, Content-Type, Accept");
    next();
});
app.use('/api', restRouter);
app.use((req, res, next) => {
    const error = new Error('Not found');
    error.message = 'Invalid route';
    error.status = 404;
    next(error);
});

app.use((error, req, res, next) => {
    if (!(error instanceof RequestError)) {
        error = new RequestError('Some Error Occurred', 500, error.message);
    }
    res.status(error.status || 500);
    let contype = req.headers['content-type'];
    var json = !(!contype || contype.indexOf('application/json') !== 0);
    if (json) {
        return res.json({ errors: error.errorList });
    } else {
        res.send(error.message)
    }
});

// kue.init();

db.sequelize.authenticate().then(function() {
    console.log('Nice! Database looks fine - ' + config.app.name);
    // scheduler.init();
    //imap.init();
}).catch(function(err) {
    console.log(err, "Something went wrong with the Database Update!")
});

app.listen(PORT, () => {
    console.log(`Server is running at PORT http://localhost:${PORT}`);
});